**Example 1: 示例**



Input: 

```
tccli cwp DescribeRecommendedProtectCpu --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "d55bcffb-2c87-43c8-afe8-543e6a0c48aa"
    }
}
```

